@@ -726,13 +726,45 @@ mod debug {
         }
         #[cfg(target_pointer_width = "32")]
         {
-            #[cfg(not(feature = "buf_stats"))]
-            assert_eq!(std::mem::size_of::<BufFile>(), 76);
-            #[cfg(feature = "buf_stats")]
-            assert_eq!(std::mem::size_of::<BufFile>(), 84);
+            #[cfg(not(any(feature = "buf_stats", feature = "buf_lru")))]
+            {
+                #[cfg(not(target_arch = "arm"))]
+                assert_eq!(std::mem::size_of::<BufFile>(), 76);
+                #[cfg(target_arch = "arm")]
+                assert_eq!(std::mem::size_of::<BufFile>(), 88);
+            }
+            #[cfg(all(feature = "buf_stats", feature = "buf_lru"))]
+            {
+                #[cfg(not(target_arch = "arm"))]
+                assert_eq!(std::mem::size_of::<BufFile>(), 88);
+                #[cfg(target_arch = "arm")]
+                assert_eq!(std::mem::size_of::<BufFile>(), 96);
+            }
+            #[cfg(all(feature = "buf_stats", not(feature = "buf_lru")))]
+            {
+                #[cfg(not(target_arch = "arm"))]
+                assert_eq!(std::mem::size_of::<BufFile>(), 84);
+                #[cfg(target_arch = "arm")]
+                assert_eq!(std::mem::size_of::<BufFile>(), 96);
+            }
+            #[cfg(all(not(feature = "buf_stats"), feature = "buf_lru"))]
+            {
+                #[cfg(not(target_arch = "arm"))]
+                assert_eq!(std::mem::size_of::<BufFile>(), 80);
+                #[cfg(target_arch = "arm")]
+                assert_eq!(std::mem::size_of::<BufFile>(), 88);
+            }
             //
+            #[cfg(not(target_arch = "arm"))]
             assert_eq!(std::mem::size_of::<Chunk>(), 28);
+            #[cfg(target_arch = "arm")]
+            assert_eq!(std::mem::size_of::<Chunk>(), 32);
+            //
+            #[cfg(not(target_arch = "arm"))]
             assert_eq!(std::mem::size_of::<(u64, usize)>(), 12);
+            #[cfg(target_arch = "arm")]
+            assert_eq!(std::mem::size_of::<(u64, usize)>(), 16);
+            //
             assert_eq!(std::mem::size_of::<Vec<Chunk>>(), 12);
             assert_eq!(std::mem::size_of::<Vec<u8>>(), 12);
         }
